function construct_brain_model(p)
% Construct brain model
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

disp(mfilename);

% Set parameters
freesurfer_dir = fullfile(p.proj_root, p.dirname.fs, p.struct_name);
brain_parm = vb_set_brain_parm(); % get default parameter
brain_parm.FS_left_file         = fullfile(freesurfer_dir, 'bem', 'lh.smoothwm.asc');
brain_parm.FS_right_file        = fullfile(freesurfer_dir, 'bem', 'rh.smoothwm.asc');
brain_parm.FS_left_infl_file    = fullfile(freesurfer_dir, 'bem', 'lh.inflated.asc');
brain_parm.FS_right_infl_file   = fullfile(freesurfer_dir, 'bem', 'rh.inflated.asc');
brain_parm.FS_left_curv_file    = fullfile(freesurfer_dir, 'bem', 'lh.curv.asc');
brain_parm.FS_right_curv_file   = fullfile(freesurfer_dir, 'bem', 'rh.curv.asc');
brain_parm.FS_left_sphere_file  = fullfile(freesurfer_dir, 'bem', 'lh.sphere.reg.asc');
brain_parm.FS_right_sphere_file = fullfile(freesurfer_dir, 'bem', 'rh.sphere.reg.asc');
brain_parm.FS_sphere_key        = 'sphere.reg';
brain_parm.FS_left_label_file   = fullfile(freesurfer_dir, 'label', 'lh.cortex.label');
brain_parm.FS_right_label_file  = fullfile(freesurfer_dir, 'label', 'rh.cortex.label');

% registration method to standard brain model.
%     = 'FS' : Freesurfer sphere file is used.
brain_parm.registration_mode = 'FS';

brain_parm.analyze_file = fullfile(p.proj_root, p.dirname.t1, ['m' p.struct_name '.nii']);
brain_parm.brain_file = [p.struct_name, '.brain.mat'];
brain_parm.area_file =  [p.struct_name, '.area.mat'];
brain_parm.act_file =   [p.struct_name, '.act.mat'];

% Construct brain model
vb_job_brain(fullfile(p.proj_root, p.dirname.brain), brain_parm);

