function prepare_leadfield(p, prefix)
% Prepare leadfield matrix
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

disp(mfilename);

% Set modality-specific parameters
switch p.dirname.modality
    case {'opm-meg', 'squid-meg'}
        % Param for head model
        Nsurf = 1; %  1-shell head model in the case of MEG data
        % Param for leadfield
        bem_mode = 1; % MEG 1-shell BEM (boundary element method)
        device   = 'NEUROMAG'; % MEG device name (it's okey for OPM as well)
        take_common_ave = false;
 
    case 'eeg'
        % Param for head model
        Nsurf = 3; %  3-shell head model in the case of EEG data
        % Param for leadfield
        bem_mode = 4; % EEG 3-shell BEM (boundary element method)
        device   = 'BRAINAMP'; % EEG device name
        take_common_ave = true;
 end

%% Construct surface model
% Set input files
% (Relative path from proj_root)
head_parm.brain_file = fullfile(p.dirname.brain, [p.struct_name, '.brain.mat']);
% (Absolute path)
head_parm.analyze_file = fullfile(p.proj_root, p.dirname.t1, ['m' p.struct_name '.nii']);
freesurfer_dir = fullfile(p.proj_root, p.dirname.fs, p.struct_name);
head_parm.fs_scalp_file = fullfile(freesurfer_dir, 'bem', 'outer_skin_surface.asc');
head_parm.freesurf_file = fullfile(freesurfer_dir, 'bem', 'inner_skull_surface.asc');
head_parm.gray_file = fullfile(p.proj_root, p.dirname.t1, ['c1m' p.struct_name '.nii']);

% Set output file (Relative path from proj_root)
head_parm.head_file = fullfile(p.dirname.modality, p.dirname.leadfield, [p.struct_name '.head.mat']);
head_parm.Nsurf = Nsurf;

% Construct surface model
% This is common across tasks
if exist(fullfile(p.proj_root,head_parm.head_file),'file')
    disp('head.mat file was already made.')
    disp('Skip ...')
else
    vb_job_head_3shell(p.proj_root, head_parm);
end

%% Make leadfield matrix
% Set input files (relative path from proj_root)
basis_parm.brain_file = head_parm.brain_file;
basis_parm.area_file  = '';
basis_parm.head_file  = head_parm.head_file;
basis_parm.device     = device;
basis_parm.bem_mode   = bem_mode;
basis_parm.Basis_mode = 1; % Single dipole perpendicular to the cortical surface

% Set input file (Ralative path from proj_root)
basis_parm.meg_file = fullfile(p.dirname.modality, p.dirname.trial, [prefix '_' p.task '.info.mat']);

% Set output file (Relative path from proj_root)
basis_parm.basis_file = fullfile(p.dirname.modality, p.dirname.leadfield, [p.task '.basis.mat']);

% Make leadfield matrix
vb_job_leadfield(p.proj_root, basis_parm)

if take_common_ave
    % Take common average
    basis_file = fullfile(p.proj_root, basis_parm.basis_file);
    load(basis_file, 'basis')
    for v = 1:size(basis, 1)
        basis(v, :) = basis(v, :)-mean(basis(v,:), 2);
    end
    vb_save(basis_file, 'basis');
end



