function import_eog_eeg(p, input_dirname, meg_dirname)
% Import EOG data from SQUID to EEG file (only for Motor and Rest of s093)
% For other subjects, EOG ch is already registered as 'EOG1' and 'EOG2' in Extra Channel of EEG file
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

disp(mfilename);

set_fig_property(4, 2, 10, 10);

% Set input directory
input_dir_eeg = fullfile(p.proj_root, p.dirname.modality, input_dirname, p.task);
input_dir_meg = fullfile(p.proj_root, meg_dirname, input_dirname, p.task);

% Set sync channel of MEG
if (strcmp(p.task, 'Motor') || strcmp(p.task, 'Rest')) && strcmp(p.sub, '093')
    ext_chname_meg = {'435'};
else
    warning('No need to conduct importing EOG.')
    return
end

% Set sync channel of EEG
ext_chname_eeg = {'EXT1'};

% EOG channels of MEG
eog_ch_name = {'416', '417'};

% EOG channels will be registered in EEG as
new_eog_ch_name = {'EOG1', 'EOG2'};
new_eog_ch_type = [1, 1];

for run = 1:p.num_run
    file_name_meg = [sprintf('run%02d', run), '.meg.mat'];
    file_name_eeg = [sprintf('run%02d', run), '.eeg.mat'];
    meg_file = fullfile(input_dir_meg, file_name_meg);
    eeg_file = fullfile(input_dir_eeg, file_name_eeg);

    %% Load data
    % Load sync signal from MEG
    loadspec = [];
    loadspec.ActiveChannel = false;
    loadspec.ChannelType = 'EXTRA';
    loadspec.ChannelName = ext_chname_meg;
    [sync_meg, ~, ~] = vb_load_meg_data(meg_file, loadspec);

    % Load sync signal from EEG
    loadspec = [];
    loadspec.ActiveChannel = false;
    loadspec.ChannelType = 'EXTRA';
    loadspec.ChannelName = ext_chname_eeg;
    [sync_eeg, ~, time_info] = vb_load_meg_data(eeg_file, loadspec);
    time_eeg = time_info.time;
    freq_eeg = time_info.sample_frequency;
    
    % Load EOG data from MEG
    loadspec = [];
    loadspec.ActiveChannel = false;
    loadspec.ChannelType = 'EXTRA';
    loadspec.ChannelName = eog_ch_name;
    [eog_meg, ~, ~] = vb_load_meg_data(meg_file, loadspec);

    %% Import 
    [eog_new, sync_onset_new, sync_onset_src, sync_onset_dst] =import_signal_using_sync(sync_meg, sync_eeg, eog_meg);

    % Compare onset index of dst and new (imported src index)
    ix_onset_new = find(sync_onset_new);
    ix_onset_dst = find(sync_onset_dst);
    dif = abs(ix_onset_dst-ix_onset_new);

    dif_ms = dif ./ freq_eeg*1000;
    max_diff_ms = num2str(max(dif)/freq_eeg*1000);
    
    %% Check result
    h=figure;
    subplot(2,1,1), plot(time_eeg, sync_onset_dst - sync_onset_new)
    xlim([-inf inf])
    xlabel('Time [sec]')
    ylabel('Differences [-1/0/1]')
    title('sync onset (MEG) - sync onset (imported EOG from MEG)')
    subplot(2,1,2), plot(dif_ms), 
    xlim([-inf inf])
    xlabel('#Pulse')
    ylabel('Differences [ms]')
    title(['Diff of pulse timing between EOG and MEG (max ' num2str(max_diff_ms) ' ms)'])
    fig_file = fullfile(p.fig_root, mfilename, [p.sub '_' p.task '_' num2str(run)]);
    vb_savefig_as_shown(h, fig_file)
    disp([fig_file '.png was saved.'])

    % Append EOG ch to input file
    append_ch = [];
    append_ch.data = eog_new;
    append_ch.name = new_eog_ch_name;
    append_ch.type = new_eog_ch_type;
    append_extra_ch(eeg_file, append_ch)
end



