function prefix_out = common_average_eeg(p, prefix_in)
% Take common average
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

disp(mfilename);

% Define additional prefix of this process
prefix_add = 'c';

% Set prefix of input file
if isempty(prefix_in)
    prefix_in_ = [];
else
    prefix_in_ = [prefix_in '_'];
end

% Set prefix of output file
prefix_out = [prefix_add prefix_in];
prefix_out_ = [prefix_out '_'];

% Set modality-specific parameters
switch p.dirname.modality
    case {'opm-meg', 'squid-meg'}
        warning('This is not for MEG data.')
        return
    case 'eeg'
        chtype = 'EEG';
        extention = '.eeg.mat';
end

for run = 1:p.num_run    
    file_name = sprintf('run%02d', run);
    file_input = fullfile(p.proj_root, p.dirname.modality, p.dirname.trial, p.task, [prefix_in_ file_name extention]);
    file_output = fullfile(p.proj_root, p.dirname.modality, p.dirname.trial, p.task, [prefix_out_ file_name extention]);

    % Load MEG/EEG data (only active ch and trial)
    loadspec = [];
    loadspec.ChannelType = chtype;
    loadspec.ActiveChannel = true; % Load active channel
    loadspec.ActiveTrial   = true; % Load active trial
    [bexp, ch_info, time_info] = vb_load_meg_data(file_input, loadspec);
    
    % Load active trial info
    info = vb_load_measurement_info(file_input, 'MEGINFO');

    % Take common reference
    fparm.common_flg = 1;
    fparm.freq = time_info.sample_frequency;
    for tr = 1:size(bexp, 3)
        bexp(:,:,tr) = vb_filter_raw_data(bexp(:,:,tr), fparm);
    end
    
    % Save baseline-corrected data
    append_ch = [];
    append_ch.data = bexp;
    append_ch.name = ch_info.Name;
    append_ch.type = ch_info.Type;
    append_ch.trial = info.ActiveTrial;
    append_data_ch(file_input, append_ch, file_output); % It makes output_file

    % Chack if average across channels becomes 0
    a = vb_load_meg_data(file_output);
    ma = squeeze(mean(a,1)); % mean across ch
    h=figure;
    plot(time_info.time, ma)
    xlim([time_info.time(1) time_info.time(end)])
    xlabel('Time [s]')
    title('Check average across channels becomes 0?')
    fig_file = fullfile(p.fig_root, mfilename, [p.sub '_' p.task '_run' num2str(run)]);
    vb_savefig_as_shown(h, fig_file)
    disp([fig_file '.png was saved.'])
end





