function convert_emg_trigger(p, input_dirname)
% Convert EMG signal to trigger
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)


disp(mfilename);

% Set input directory
input_dir = fullfile(p.proj_root, p.dirname.modality, input_dirname, p.task);

% Set output directory (overwrite input OPM data)
output_dir = input_dir;

% Set loadspec
loadspec = [];
loadspec.ChannelType='EXTRA';
loadspec.ChannelName = {'trigger_emg'}; % EMG ch is defined in 'correct_emegch_squid.m'
% Detected trigger will be registered as 'trigger_pulse'
trig_ch_name = 'trigger_pulse';
trig_ch_type = -1;

% Parameters are specified for each sub and run
% It was defined in set_parameters.m
th_scale = p.emg_detect.th_scale;
len_close = p.emg_detect.len_close;
len_open = p.emg_detect.len_open;

for run = 1:p.num_run
    file_name = [sprintf('run%02d', run), '.meg.mat'];
    
    % Set input file
    meg_file = fullfile(input_dir, file_name);
        
    % Load EMG data
    [emg_data,~,time_info] = vb_load_meg_data(meg_file, loadspec);
    time = time_info.time;
    
    % Detect trigger
    [trig_data, ~, ~, ~, ~] = detect_onset(emg_data, th_scale(run), len_close(run), len_open(run));
    
    % Check detected trigger
    ncol = 5;
    wincol = fix( size(emg_data,2)/ncol );
    emg_data_plot = emg_data ./ max(emg_data);
    h=figure;
    for col=1:ncol
        subplot(ncol,1,col)
        ixcol = (col-1)*wincol+1 : col*wincol;
        plot(time(ixcol), emg_data_plot(ixcol)'), hold on, plot(time(ixcol), trig_data(ixcol)', 'r')
        xlim([-inf inf])
        if col==1, title('Detected trigger onsets from EMG signals'), end
        if col==ncol, xlabel('Time [sec]'), legend({'EMG','Onset'},'location','northeastoutside'), end
    end

    fig_file = fullfile(p.fig_root, mfilename, p.dirname.modality, [p.sub '_run' num2str(run)]);
    vb_savefig_as_shown(h, fig_file)
    disp([fig_file '.png was saved.'])    

    % Append trigger ch to input file
    append_ch = [];
    append_ch.data = trig_data;
    append_ch.name = trig_ch_name;
    append_ch.type = trig_ch_type;
    append_extra_ch(meg_file, append_ch)
end

end
