function correct_emgch_squid(p, input_dirname)
% Correct mis-defined EMG channel of Motor data
% Points: 1.EMG channel (Ch416) is defined as inactive ch except for s093
%         2.In case of s093, EMG is defined as Ch418
% Therefore, we re-define new EMG channel as 'trigger_emg'
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

disp(mfilename);

% Set input directory
input_dir = fullfile(p.proj_root, p.dirname.modality, input_dirname, p.task);

% Set output directory (overwrite input OPM data)
output_dir = input_dir;

% Set trigger or sync channel
switch p.sub
    case {'002', '005', '006', '095'}
        emg_ch = '416';
    case {'093'}
        emg_ch = '418';
end

new_emg_ch = 'trigger_emg';
emg_ch_type = -2;

% Correct the definition
for run = 1:p.num_run
    file_name = [sprintf('run%02d', run), '.meg.mat'];
    meg_file = fullfile(input_dir, file_name);
    
    % Load EMG data
    loadspec = [];
    loadspec.ActiveChannel = false; % Load inactive channel
    loadspec.ChannelName = {emg_ch}; % Specify the EMG channel
    [emg, channel_info, time_info] = vb_load_meg_data(meg_file, loadspec);

    % Append corrected EMG ch to input file
    append_ch = [];
    append_ch.data = emg;
    append_ch.name = new_emg_ch;
    append_ch.type = emg_ch_type;
    append_extra_ch(meg_file, append_ch)
end
