function [prefix_out, index_selected_trials] = select_trials(p, prefix_in, num_trial, index_selected_trials)
% Select the trials randomly.
% If index_selected_trials is input, specified trials are selected.
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

disp(mfilename);

if ~exist('selected_trials','var')
    index_selected_trials = [];
end

if ~exist('num_trial','var') || isempty(num_trial)
    warning(['Number of trials is not specified.' newline 'Skip selection.'])
    prefix_out = prefix_in;
    return
end

% Define additional prefix of this process
prefix_add = 's';

% Set prefix of input file
if isempty(prefix_in)
    prefix_in_ = [];
else
    prefix_in_ = [prefix_in '_'];
end

% Set prefix of output file
prefix_out = [prefix_add prefix_in];
prefix_out_ = [prefix_out '_'];

% Set input files
file_input = fullfile(p.proj_root, p.dirname.modality, p.dirname.trial, [prefix_in_ p.task '.info.mat']);

% Set output file
file_output = fullfile(p.proj_root, p.dirname.modality, p.dirname.trial, [prefix_out_ p.task '.info.mat']);

% Load fileinfo
INFO = load(file_input);

% Check ActiveTrial of input data
active_trial = INFO.fileinfo.ActiveTrial;
index_active_trial = find(active_trial);
num_active_trial = length(index_active_trial);
if num_trial > num_active_trial 
    error('Input ''num_trial'' is larger than ''ActiveTrial''. ')
end

% Select num_trial from ActiveTrial
if isempty(index_selected_trials)
    rng(0,'twister') % Fix the random seed for tutorial
    index_rnd = sort(randperm(num_active_trial, num_trial));
    index_selected_trials = index_active_trial(index_rnd);
else
    disp('Input ''index_selected_trials'' is used.')
end
new_active_trial = zeros(size(active_trial));
new_active_trial(index_selected_trials) = 1;

disp(['Selected ' num2str(num_trial) '/' num2str(num_active_trial) ' trials.'])

% Overwrite fileinfo
INFO.fileinfo.ActiveTrial = new_active_trial;

% Save result
save(file_output, '-struct', 'INFO')
disp([file_output ' was saved.'])


