function p = set_ic(p)
% Append manually selected brain/noise ICs to parameters.
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

%% Define tables 
% Brain ICs
brain_table_squid = cell2table(cell(5,4),...
    'VariableNames', {'Auditory', 'Motor', 'Somatosensory', 'Rest'}, ...
    'RowNames', {'002', '005', '006', '093', '095'});

% Noise ICs
noise_table_squid = cell2table(cell(5,4),...
    'VariableNames', {'Auditory', 'Motor', 'Somatosensory', 'Rest'}, ...
    'RowNames', {'002', '005', '006', '093', '095'});

%% Set brain ICs to the table
% No manual selection

%% Set noise ICs to the table
% --- SQUID ---
% 002
noise_table_squid.Auditory{'002'}      = [17,27,47,67];
noise_table_squid.Motor{'002'}         = [27,28,29,30,35,44,58,65];
noise_table_squid.Somatosensory{'002'} = [19,22,26,35,70];
% 005
noise_table_squid.Auditory{'005'}      = [6,37,58];
noise_table_squid.Motor{'005'}         = [5,18,36,50,58,67];
noise_table_squid.Somatosensory{'005'} = [5,24,41,65,94];
% 006
noise_table_squid.Auditory{'006'}      = [4,7,39];
noise_table_squid.Motor{'006'}         = [5,7,10,24,36];
noise_table_squid.Somatosensory{'006'} = [8,9,12,36];
% 093
noise_table_squid.Auditory{'093'}      = [1,7,11,34,53];
noise_table_squid.Motor{'093'}         = [1,15,23,34];
noise_table_squid.Somatosensory{'093'} = [1,12,16,43,57,66];

%% Extract param for specified subject and task
switch p.dirname.modality
    case 'squid-meg'
        brainic = brain_table_squid.(p.task){p.sub};
        noiseic = noise_table_squid.(p.task){p.sub};
    case 'eeg'
        brainic = brain_table_eeg.(p.task){p.sub};
        noiseic = noise_table_eeg.(p.task){p.sub};
end

% Append to the parameter
p.ica.brain_ic = brainic;
p.ica.noise_ic = noiseic;