function make_tfr(p, input_dirname, prefix_in, trigger_dirname)
% Convert data to time-freq representation
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

disp(mfilename);

% Set prefix of reference MEG/EEG file
if isempty(prefix_in)
    prefix_in_ = [];
else
    prefix_in_ = [prefix_in '_'];
end

% Set modality-specific parameters
switch p.dirname.modality
    case 'opm-meg'
        extention = '.meg.mat';
    case 'squid-meg'
        extention = '.meg.mat';
    case 'eeg'
        extention = '.eeg.mat';
end

% Check trigger dir
if ~exist('trigger_dirname','var') || isempty(trigger_dirname)
    trigger_dirname = input_dirname;
end

%% Set options for TFR
tfr_parm = [];

% Use wavelet
tfr_parm.method = 'wavelet';

% Make tfr of ext and ref ch as well
tfr_parm.make_ext = true;
tfr_parm.make_ref = true;

% Set freq of interests from band-pass filtering options
tfr_parm.min_freq = p.filter.bandpass_freq(1);
tfr_parm.max_freq = p.filter.bandpass_freq(2);
tfr_parm.num_freq = tfr_parm.max_freq-tfr_parm.min_freq+1; % step size

% Params of wavelet
tfr_parm.central_freq = 1;
tfr_parm.fwhm = 3;

% Scale of frequency 
tfr_parm.freq_scale = 'linear'; % or log

% Since compute TFR from non-segmented data, Cone of Influence is not a
% problem after trial-segmentation
tfr_parm.mask_coi = true;


%% Start making TFR file
data_files = cell(p.num_run, 1);
for run = 1:p.num_run
    % --- Make tfr file
    file_name = sprintf('run%02d', run);
    % Set input file (abs path)
    meg_file = fullfile(p.proj_root, p.dirname.modality, input_dirname, p.task, [file_name extention]);
    % Set output file (abs path)
    tfr_file = fullfile(p.proj_root, p.dirname.modality, input_dirname, p.task, [file_name '.tfr.mat']);
    % Each ch will be saved as a separated file in 'saveman.data_dir'
    tfr_parm.saveman.data_dir = ['./' file_name]; % Relative path from dir of tfr_file

    % Make tfr file
    vb_make_tfr_data(meg_file, tfr_file, tfr_parm)

    % --- Make trial file
    % Set input file (abs path)
    proc_spec = [];
    proc_spec.trig_file = fullfile(p.proj_root, p.dirname.modality, trigger_dirname, p.task, [file_name '.trig.mat']);
    % Set output file (abs path)
    trial_file = fullfile(p.proj_root, p.dirname.modality, p.dirname.trial, p.task, [file_name '.tfr.mat']);
    % Make trial data
    vb_make_tfr_trial_data(tfr_file, proc_spec, trial_file);

    % --- Remove tfr_file to save memory
    vb_delete_tfr_data(tfr_file)

    data_files{run} = trial_file;
end

% --- Combine run files
% Set output file
% Use same prefix as MEG/EEG file
combined_file = fullfile(p.proj_root, p.dirname.modality, p.dirname.trial, [prefix_in_ p.task '_tfr.info.mat']);
% Make info.mat file
vb_make_tfr_fileinfo(data_files, combined_file);

% --- Set same active channels and trials as MEG/EEG data
% Load fileinfo
F = load(combined_file);

% Load template fileinfo
combined_file_ref = fullfile(p.proj_root, p.dirname.modality, p.dirname.trial, [prefix_in_ p.task '.info.mat']);
F_ref = load(combined_file_ref);

% Overwrite
F.fileinfo.ActiveChannel = F_ref.fileinfo.ActiveChannel;
F.fileinfo.ActiveTrial   = F_ref.fileinfo.ActiveTrial;
F.fileinfo.cond_id       = F_ref.fileinfo.cond_id;

save(combined_file, '-struct', 'F')

