% debug 
% fmri constraint dipole methods
%
clear all
close all

%% 
rdir = ['/home/dcfs2/oyamashi/matlab/vbmeg/debug/'];
brainfile  = [rdir 'testdata/10000fb.brain.mat'];
basisfile = [rdir 'testdata/simudata/c0000fc_bem.basis.mat'];


load(basisfile,'basis');
load(brainfile, 'nextIX','nextDD')

Nt = 100;
[Nj,Nch] = size(basis);
basis = basis';
ix_rnd = randperm(Nj);

for id = 1 : 100
    Dix_true = ix_rnd(id);
    
    fprintf('True dipole index  : %d\n', Dix_true);
    %% data generation
    J0 = sin(pi*[1:Nt]/Nt).^2;
    bexp0 = basis(:,Dix_true)*J0;
    slevel = sqrt(sum(bexp0(:).^2)/Nt/Nch);  % signal level defined by sqrt(tr(SS')) 
    SN_sensor = 0.05;
    rndm = randn(Nch,Nt); 
    s_noise = SN_sensor * slevel* rndm; 
    bexp = bexp0 + s_noise;

    %% source localization    
    
% %%% optional input 
% option.twin_meg  = [1 400]; % Time window for analysis
% option.Tperiod   = 100; % Time period for current estimation 
% option.Tnext     = 100; % Time step for next period
% option.temporal_filter = 1;

%% ------------------------ Don't modify
%% Defaults
twin_meg = [1 Nt];
Tperiod = Nt;
Tnext = Nt;
temporal_filter = 0;

%% Replace Defaults
if exist('option') == 1 & isfield(option,'twin_meg')
    twin_meg = option.twin_meg;
    Nt = option.twin_meg(2)-option.twin_meg(1)+1;
end
if exist('option') == 1 & isfield(option,'Tperiod')
    Tperiod = option.Tperiod;
end
if exist('option') == 1 & isfield(option,'Tnext')
    Tnext = option.Tnext;
end
if exist('option') == 1 & isfield(option,'temporal_filter')
    temporal_filter = option.temporal_filter;
end

% average data
B = mean(bexp(:,[twin_meg(1):twin_meg(2)],:), 3); 
if temporal_filter
    B = temporal_smooth(B);
end

% area information
for i = 1 : 1
    area{i}.Iextract = nextIX{Dix_true};
end

% dipole method for each time window 
Nwindow  = ceil((Nt - Tperiod)/Tnext + 1); % Number of periods
Tbegin	 = 1:Tnext:((Nwindow-1)*Tnext + 1);		% Start time index
Tend	 = min(Tbegin + Tperiod - 1, Nt);	% End   time index
Twindow  = [Tbegin' Tend']; 
option.Ntrain = 1;
for nw = 1 : Nwindow
    Bin = B(:, [Twindow(nw,1):Twindow(nw,2)]);
    [D, sig2, Dix] = fmri_dipole_estimation(basis, Bin, area, [], option);
end

ind=find(nextIX{Dix_true} == Dix);
loc_error(id) = nextDD{Dix_true}(ind);
max(D);

end