% fmri constraint dipole methods
%
clear all
close all
%%% input file
rdir = ['/home/dcfs2/oyamashi/matlab/vbmeg/debug/'];
areafile  = [rdir 'testdata/TD_brodmann.area.mat'];
basisfile = [rdir 'testdata/simudata/c0000fc_bem.basis.mat'];
megfile   = [rdir 'testdata/simudata/retino_bk10_gS10_gB10.meg.mat'];
area_key  = {'V1UL_3', 'V1DL_4', 'V1DR_3','V1UR_3'};

% %%% optional input 
option.twin_meg  = [1 400]; % Time window for analysis
option.Tperiod   = 100; % Time period for current estimation 
option.Tnext     = 100; % Time step for next period
option.temporal_filter = 0;

%% ------------------------ Don't modify
load(megfile, 'bexp')
load(basisfile, 'basis');
[Nch, Nt, Ntrial] = size(bexp);
basis = basis';

%% Defaults
twin_meg = [1 Nt];
Tperiod = Nt;
Tnext = Nt;
temporal_filter = 0;

%% Replace Defaults
if exist('option') == 1 & isfield(option,'twin_meg')
    twin_meg = option.twin_meg;
    Nt = option.twin_meg(2)-option.twin_meg(1)+1;
end
if exist('option') == 1 & isfield(option,'Tperiod')
    Tperiod = option.Tperiod;
end
if exist('option') == 1 & isfield(option,'Tnext')
    Tnext = option.Tnext;
end
if exist('option') == 1 & isfield(option,'temporal_filter')
    temporal_filter = option.temporal_filter;
end

% average data
B = mean(bexp(:,[twin_meg(1):twin_meg(2)],:), 3); 
if temporal_filter
    B = temporal_smooth(B);
end

% area information
for i = 1 : length(area_key)
    area{i} = get_area(areafile, area_key{i});
end

% dipole method for each time window 
Nwindow  = ceil((Nt - Tperiod)/Tnext + 1); % Number of periods
Tbegin	 = 1:Tnext:((Nwindow-1)*Tnext + 1);		% Start time index
Tend	 = min(Tbegin + Tperiod - 1, Nt);	% End   time index
Twindow  = [Tbegin' Tend']; 
op.Nstart = 20;
for nw = 1 : Nwindow
    Bin = B(:, [Twindow(nw,1):Twindow(nw,2)]);
    [Dts{nw}, sig2(nw), Dix{nw}, Dtval{nw}] = fmri_dipole_estimation2(basis, Bin, area, [], op);
end
    