function itpc = calc_itpc(tfr)
% Compute Inter-Trial Phase Clustering
% tfr: Time-freq representaton of MEG/EEG data
%      Single and multiple ch input is ok
%      [ch * freq * time * trial] or [freq * time * trial]

if ndims(tfr)==3
    do_squeeze = true;
    % Append ch dim
    tmp = zeros(1,size(tfr,1),size(tfr,2),size(tfr,3));
    tmp(1,:,:,:) = tfr;
    tfr = tmp;
else
    do_squeeze = false;
end

[num_ch, num_freq, num_time, num_trial] = size(tfr);


itpc = zeros(num_ch, num_freq, num_time);

for ch=1:num_ch
    % Extract single ch
    tfr_1ch = squeeze( tfr(ch,:,:,:) );
    for fr=1:num_freq
        % Extract single freq
        tfr_1ch_1fr = squeeze( tfr_1ch(fr,:,:) );
        % Calc ITPC
        itpc(ch,fr,:) = abs(mean(exp(1i*angle(tfr_1ch_1fr)),2));
    end
end

if do_squeeze
    % Remove ch dim
    % itpc = squeeze(itpc); % It may delete freq or time dim
    itpc = shiftdim(itpc,1); % It delete the first dim when first dim=1
end