function trial_idx = get_active_trial_index(loadspec, meginfo)
func_ = mfilename;

% Priority : TrialNumber > ActiveTrial
% If TrialNumber is specified, get index of specified trials (ActiveTrial is ignored).
% If TrialNumber is not specified and ActiveTrial is true, get index of active trials.
% If TrialNumber is not specified and ActiveTrial is false, get index of all trials.

% If there is only 1 trial, get index 1 (TrialNumber and ActiveTrial are ignored).

N_trial = vb_info_get_Nrepeat(meginfo);
if N_trial == 1
    trial_idx = 1;
else
    org_info = meginfo;
    org_trial = org_info.Trial;
    org_trial_idx = [org_trial.number];

    if isempty(loadspec.TrialNumber)
        % If TrialNumber is empty, set all trial
        cur_trial = vb_info_get_trial_data(meginfo);
        trial_idx = 1:length(cur_trial);
    else
        % If TrialNumber is specified, trial is selected by TrialNumber
        cur_trial = vb_info_get_trial_data(meginfo, loadspec.TrialNumber);
        dst_trial_idx = [cur_trial.number];
        [result, trial_idx] = ...
            vb_util_check_numerical_lists(org_trial_idx, dst_trial_idx);
    end     % if ~isempty(loadspec.TrialNumber)

    if length(trial_idx) ~= length(cur_trial)
        error('(%s) bad trial_idx', func_);
    end

    % Priority : TrialNumber > ActiveTrial
    % (If TrialNumber is not equal to org_trial_idx, ActiveTrial information in meginfo is ignored)
    if loadspec.ActiveTrial && isequal(org_trial_idx(:), loadspec.TrialNumber(:))
        active_list = vb_info_get_active_trial(meginfo);
        if isempty(active_list)
            active_list = [cur_trial.Active];
        end
        trial_idx = trial_idx(active_list==true);
    end
end


