function [Jmap, ix_act, csd] = load_current_dics(current_file, cur_type, norm_mode)
% Load estimated current by job_dics.
% curr_type - current type
%         = 1 : Z-current : Cortical current on reduced vertex.
%         = 2 : Current   : Cortical current on all vertex.   [Default]
%
% norm_mode - normalization mode
%         = F : Pseudo F-ratio.
%         = P : Power of data.   [Default]
%         = R : Power of data / power of noise.
% 2024.09.03 k_suzuki

if ~exist('cur_type', 'var') || isempty(cur_type)
    cur_type = 2;
end

if ~exist('norm_mode', 'var') || isempty(norm_mode)
    norm_mode = 'P';
end

% Load results of DICS and index of currents
load(current_file, 'Model', 'ix_act', 'dics_parm', 'Nvertex')
tfrfile = dics_parm.tfrfile;

% Load ch and time information
ch_info = get_channel_info(tfrfile);
chnames = ch_info.Name;

tfr_info = get_tfr_info(tfrfile);
time_sec = tfr_info.time;
freq_hz  = tfr_info.frequency;

% Prepare CSD for visualization
Cm = abs(Model.CSDm);
Cn = abs(Model.CSDn);

% Set selected results as reconstructed currents
switch norm_mode
    case 'F'
        % Pseudo F-ratio
        cur = Model.F;
        csd = abs( (Model.CSDm-Model.CSDn) ./Model.CSDn ); % F-ratio like
    case 'P'
        % Power of data
        cur = Model.Pm;
        csd = abs(Model.CSDm);
    case 'R'
        % Power of data / power of noise
        cur = Model.Pm./Model.Pn;
        csd = abs(Model.CSDm./Model.CSDn);
end

switch cur_type
    case 1
        Jmap = cur;
    case 2
        % Project current map to whole cortex
        Jmap = zeros(Nvertex, 1);
        Jmap(ix_act,:) = cur;
end
