function tfr = normalize_tfr(tfr, twin_base_ix, normalize_type)
% Normalize TFR data using data in baseline 
% When trial-averaging was not performed yet, do trial-wise correction
%  tfr         : TFR data after trial-segmentation
%                (complex value, psd or trial-averaged data is ok)
%  twin_base_ix: Index of baseline windox
%                twin_bse_ix = [from_base_ix, to_base_ix]
%  normalize_type : {'db', 'divide', 'z'}

[num_ch, num_freq, num_time, num_trial] = size(tfr);

if ~exist('normalize_type','var') || isempty(normalize_type)
    normalize_type = 'db';
end

% Calc mean and std of baseline across time for each trial (not trial averaging)
base_mean = nanmean( tfr(:, :, twin_base_ix(1):twin_base_ix(2), :), 3);
base_std  = nanstd( tfr(:, :, twin_base_ix(1):twin_base_ix(2), :), [], 3);

% Repmat
base_mean_rep = repmat(base_mean, [1,1,num_time,1]);
base_std_rep  = repmat(base_std, [1,1,num_time,1]);

switch normalize_type
    case 'db'
        tfr = 10*log10(tfr ./ base_mean_rep);
    case 'divide'
        tfr = tfr ./ base_mean_rep;
        %tfr = tfr ./ base_std_rep;
    case 'z'
        tfr = (tfr-base_mean_rep) ./ base_std_rep;
end

end