function plot_tfr_reproducibility(tfr, freq, time, time_of_interest, iterations, plot_imagesc)
% Calc reproducibility across trials 
% Correlation coefficients are computed within time of interet

if ndims(tfr)==4 && size(tfr,1)==1
    % Remove ch dim
    tfr = shiftdim(tfr,1); % It delete the first dim when first dim=1
else
    error('Check dim of tfr');
end

[num_freq, num_time, num_trial] = size(tfr);

if ~exist('iterations','var') || isempty(iterations)
    iterations = 10;
end
if ~exist('plot_imagesc','var') || isempty(plot_imagesc)
    plot_imagesc = false;
end

% Init
result = zeros(num_freq, num_trial);

% Find index
ix_toi = dsearchn(time', time_of_interest');

for ff=1:num_freq
    % Calc template as averaged data of all trials
    tf_f = squeeze( tfr(ff,:,:) );
    ave_all = mean(tf_f(ix_toi(1):ix_toi(2),:),2); 
    ave_all(isnan(ave_all)) = 0;

    for ii=1:iterations
        for tt=5:num_trial % start at 5 trials...
            % Randomly select tt trials
            % trials = randsample(1:num_trial, tt); % Requires the stats toolbox
            trials = randperm(num_trial); 
            trials = trials(1:tt);
            
            % Compute power time series from the random selection of trials
            ave_ntrials = mean(tf_f(ix_toi(1):ix_toi(2),trials),2);
            ave_ntrials(isnan(ave_ntrials)) = 0;

            % Compute Pearson correlation
            cc = corrcoef(ave_all, ave_ntrials);
            r = cc(1,2);
            % Store result
            result(ff,tt) = result(ff,tt) + r;
        end
    end
end

result = result./iterations;

if plot_imagesc
    imagesc(5:num_trial,freq,squeeze(result(:,5:end)))
    axis xy
else
    contourf(5:num_trial,freq,squeeze(result(:,5:end)),40,'linecolor','none')
end
cb = colorbar;
cb.Label.String = 'Correlation coefficient';
cb.Label.Rotation = 270;
cb.Label.VerticalAlignment = 'bottom';
set_axis
set(gca,'clim',[.3 1])
xlabel('Number of trials')
ylabel('Frequency')
title('Frequency-wise reproducibility')

%% end
