function [tfr, meginfo] = segment_tfr_data(tfr, meginfo, load_spec)
% Segment TFR data into trials
% Note: If trial-segmentation is performed, meginfo.ActiveTrial is initialized
%
% 2023.11.10 k_suzuki
%            Separated from vb_load_tfr_data.
%

%% Check trial
% If Trigger, Pretrigger, and Posttrigger are set in load_spec,
% data will be segmented to trials.
target_sample = vb_loadspec_make_trial_sample(load_spec);
num_trial     = vb_info_get_Nrepeat(meginfo); 

if isempty(target_sample)
    % No trial segmentation
    do_segmentation = false;
elseif num_trial~=1
    % If data is already segmented, no trial segmentation is conducted
    do_segmentation = false;
else
    do_segmentation = true;
end

if do_segmentation
    % Trial segmentation 
    tfr = inner_segment_tfr(tfr, target_sample);

    % Set new #of time and trial
    num_time_new  = target_sample(1,2)-target_sample(1,1)+1;
    num_trial_new = size(target_sample, 1);

    % Update fields of meg_info 
    meginfo.Nsample     = num_time_new;
    meginfo.Nrepeat     = num_trial_new;
    meginfo.Pretrigger  = load_spec.Pretrigger;
    meginfo.ActiveTrial = true(num_trial_new,1);
    % Set new cond_id (set cond_id of the first trial to all trials)
    if isfield(meginfo, 'cond_id')
        cond_tmp = meginfo.cond_id(1);
    else
        cond_tmp = 1;
    end
    meginfo.cond_id = ones(1,num_trial_new)*cond_tmp;
    
    % Set new Trial structure
    meginfo.Trial = [];
    for tr=1:num_trial_new
        meginfo.Trial(tr).Active = true; % New trials are all active
        meginfo.Trial(tr).number = tr;
        meginfo.Trial(tr).sample = [target_sample(tr,1):target_sample(tr,2)]';
    end
end

end% End of the main function

function tfr_new = inner_segment_tfr(tfr, target_sample)
if ~isempty(tfr)
    [num_ch, num_freq, num_time, num_trial] = size(tfr);
    num_trial_new = size(target_sample,1);
    num_time_new = target_sample(1,2)-target_sample(1,1)+1;

    tfr_new = zeros(num_ch, num_freq, num_time_new, num_trial_new);
    for tr = 1:num_trial_new
        tfr_new(:,:,:,tr) = tfr(:,:,target_sample(tr,1):target_sample(tr,2));
    end
else
    tfr_new = [];
end
end % --- end of inner_segment_tfr()
