function S = make_vsh(pick, Qpick, lmax)
%--- Inputs ---
% pick  : Sensor position matrix (Nm*3)
% Qpick : Sensor orientation matrix (Nm*3)
% lmax  : lmax of VSH function (Nh=lmax^2+2*lmax)

%--- Outputs ---
% H     : Estimated coefficients of vector cpherical harmonics (Nh*Nt)
% S     : Vector spherical harmonics function (Nm*Nh)
% P     : Projection matrix from B to null space (= residual)
% Hfilter  : Matrix converting B to Hbar

% If lmax is not specified, set to 1
% This is equivalent to HFC
% in case of h = (y,z,x)'
if ~exist('lmax', 'var') || isempty(lmax)
    lmax = 1;
end

% Total num of harmonics
nh = lmax^2 + 2*lmax; 

%% Compute VSH function
% Compute VSHU using the function by T.Tierney. 
% From [https://github.com/tierneytim/OPM/blob/master/spm_opm_vslm.m]
% See reference [https://doi.org/10.1016/j.neuroimage.2022.119338]

% Set parameters
parm_vsh = [];
parm_vsh.li    = lmax;
parm_vsh.reg   = 1; % 0:neural space A (Eq.A2), 1:interference space B (Eq.A3)
parm_vsh.v     = pick;
parm_vsh.o     = Qpick;
parm_vsh.scale = 1;

% Compute VSH
S = spm_opm_vslm(parm_vsh);