function B = convert_eeg2meg(E)
% Convert the contents of eeg.mat to meg.mat.
% E : struct contains all of eeg.mat.
%     e.g., E = load(test.eeg.mat)
% B : struct contains all of meg.mat.
%     e.g., B = load(test.meg.mat) 
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

B = [];

% Convert EEGinfo to MEGinfo
B.MEGinfo = inner_convert_EEGinfo2MEGinfo(E.EEGinfo);

% eeg_data are separated into bexp or bexp_ext 
% refmg is defined as empty
ix_bexp = E.EEGinfo.ChannelInfo.ID;
ix_bexp_ext = E.EEGinfo.ExtraChannelInfo.Channel_id;

if isfield(E,'eeg_data')
B.bexp = E.eeg_data(ix_bexp,:,:);
B.bexp_ext = E.eeg_data(ix_bexp_ext,:,:);
B.refmg = [];
end

% Register EEGinfo.Coord as pick
% Qpick is defined as zeros
B.pick = E.EEGinfo.Coord;
B.Qpick = zeros(size(E.EEGinfo.Coord));
B.CoordType = E.EEGinfo.CoordType;

% Set Measurement as MEG
B.Measurement = 'MEG';

% ref_pick and ref_Qpick are defined as empty
B.ref_pick = [];
B.ref_Qpick = [];

% --- INNER FUNCTIONS -------------------------------------------------------- %
%
% --- inner_convert_EEGinfo2MEGinfo()
%
%   returned fields of MEGinfo : 
%     Nchannel         <-- Nchannel
%     Nsample          <-- Nsample
%     Pretrigger       <-- Pretrigger
%     SampleFreq       <-- SampleFrequency
%     Nrepeat          <-- Nrepeat
%     Trial            <-- Trial
%     Vcenter          <-- Vcenter
%     Vradius          <-- Vradius
%     MRI_ID           <-- MRI_ID
%     MEGch_name       <-- ChannelName
%     MEGch_id         <-- ChannelID
%     ActiveChannel    <-- ActiveChannel
%     ActiveTrial      <-- ActiveTrial
%     device           <-- Device
%     Measurement      <-- Measurement
%     ChannelInfo      <-- ChannelInfo
%     ExtraChannelInfo <-- ExtraChannelInfo
%     (saveman)        <-- File & DataType
%
function MEGinfo = inner_convert_EEGinfo2MEGinfo(EEGinfo)
  if ~isfield(EEGinfo, 'Nchannel'),        EEGinfo.Nchannel = []; end
  if ~isfield(EEGinfo, 'Nsample'),         EEGinfo.Nsample = []; end
  if ~isfield(EEGinfo, 'Pretrigger'),      EEGinfo.Pretrigger = []; end
  if ~isfield(EEGinfo, 'SampleFrequency'), EEGinfo.SampleFrequency = []; end
  if ~isfield(EEGinfo, 'Nrepeat'),         EEGinfo.Nrepeat = []; end
  if ~isfield(EEGinfo, 'Trial'),           EEGinfo.Trial = []; end
  if ~isfield(EEGinfo, 'Vcenter'),         EEGinfo.Vcenter = []; end
  if ~isfield(EEGinfo, 'Vradius'),         EEGinfo.Vradius = []; end
  if ~isfield(EEGinfo, 'ChannelName'),     EEGinfo.ChannelName = []; end
  if ~isfield(EEGinfo, 'ChannelID'),       EEGinfo.ChannelID = []; end
  if ~isfield(EEGinfo, 'ActiveChannel'),   EEGinfo.ActiveChannel = []; end
  if ~isfield(EEGinfo, 'ActiveTrial'),     EEGinfo.ActiveTrial = []; end
  if ~isfield(EEGinfo, 'Device'),          EEGinfo.Device = []; end
  if ~isfield(EEGinfo, 'Measurement'),     EEGinfo.Measurement = []; end
  if ~isfield(EEGinfo, 'MRI_ID'),          EEGinfo.MRI_ID = []; end
  if ~isfield(EEGinfo, 'ChannelInfo'),     EEGinfo.ChannelInfo = []; end
  if ~isfield(EEGinfo, 'ExtraChannelInfo'),EEGinfo.ExtraChannelInfo = []; end
  if ~isfield(EEGinfo, 'File'),            EEGinfo.File = []; end
  if ~isfield(EEGinfo, 'DataType'),        EEGinfo.DataType = []; end

  MEGinfo.Nchannel      = EEGinfo.Nchannel;
  MEGinfo.Nsample       = EEGinfo.Nsample;
  MEGinfo.Pretrigger    = EEGinfo.Pretrigger;
  MEGinfo.SampleFreq    = EEGinfo.SampleFrequency;
  MEGinfo.Nrepeat       = EEGinfo.Nrepeat;
  MEGinfo.Trial         = EEGinfo.Trial;
  if isfield(EEGinfo, 'cond_id')
      MEGinfo.cond_id   = EEGinfo.cond_id;
  end
  MEGinfo.Vcenter       = EEGinfo.Vcenter;
  MEGinfo.Vradius       = EEGinfo.Vradius;
  MEGinfo.MEGch_name    = EEGinfo.ChannelName;
  MEGinfo.MEGch_id      = EEGinfo.ChannelID;
  MEGinfo.ActiveChannel = EEGinfo.ActiveChannel;
  MEGinfo.ActiveTrial   = EEGinfo.ActiveTrial;
  MEGinfo.device        = EEGinfo.Device;
  MEGinfo.Measurement   = EEGinfo.Measurement;
  MEGinfo.MRI_ID        = EEGinfo.MRI_ID;
  MEGinfo.ChannelInfo   = EEGinfo.ChannelInfo;
  MEGinfo.ExtraChannelInfo = EEGinfo.ExtraChannelInfo;

  if ~isempty(EEGinfo.File)
      MEGinfo.saveman.data_dir = ...
          [EEGinfo.File.OutputDir '/' EEGinfo.File.DataDir];
  else
      MEGinfo.saveman.data_dir = [];
  end

  if ~isempty(EEGinfo.DataType)
      MEGinfo.saveman.precision = EEGinfo.DataType(1);
  else
      MEGinfo.saveman.precision = [];
  end
  
  return;
%
% --- end of inner_convert_EEGinfo2MEGinfo()
