function plot_rows(data, label, ix_highlight, flip_order)
% Visualize each row of input data.
% data  : The size of data is [nch, ntime].
% label : Labels of each channel. 
% ix_highlight : Vector index (e.g.[1,5]) or logical index (e.g.[1 0 0 0 1])
% flip_order   : True or False
%                Note. without flipping, the first ch comes to the bottom.

% Check input
[nch, ntime] = size(data);

% Check options
if ~exist('label','var')
    label = string(1:nch);
end

if ~exist('ix_highlight','var')
    ix_highlight = [];
end

if ~exist('flip_order','var') || isempty(flip_order)
    flip_order = true;
end

% Vector ix -> logical ix
if length(ix_highlight)~=nch
    ixtemp = false(1,nch);
    ixtemp(ix_highlight) = true;
    ix_highlight = ixtemp;
end

% Flipping the order of data 
if flip_order
    data = flip(data,1);
    label = flip(label);
    ix_highlight = flip(ix_highlight);
end

% Set colors
color1 = [.2 .2 .2]; % Default
color2 = [0.6350 0.0780 0.1840]; % Highlight

line_color = repmat(color1, size(data,1),1);
line_color(ix_highlight,:) = repmat(color2, size(line_color(ix_highlight,:),1),1);

% Scale data
data = data - mean(data,2);
data = data ./ max(data(:));
y_ = repmat([1:size(data,1)]', 1,size(data,2));
data = data + y_;

% Visualization
plot(data')
yticks(1:size(data,1))
yticklabels(label)
ylim([0 max(data(:))])
xlim([0 size(data,2)])
set(gca, 'XTick', [], 'box', 'off', 'tickdir', 'out')
set(gca,'TickLabelInterpreter','none')
ax=gca;
ax.FontUnits = 'normalized';
ax.FontSize = 1/size(data,1);
ax.ColorOrder = line_color;