function check_brain_model(p)
% Construct brain model
%
% Y. Takeda 2018-09-28
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

disp(mfilename);
close all

% Set figure properties
set_fig_property(4, 1, 10, 10);

% Directory to save figures
save_dir = fullfile(p.fig_root, mfilename);

% Set T1 and brain model files
T1_file = fullfile(p.proj_root, p.dirname.t1, ['m' p.struct_name '.nii']);
brain_file = fullfile(p.proj_root, p.dirname.brain, [p.struct_name, '.brain.mat']);

% Load T1 image
[B, Vdim, Vsize] = vb_load_analyze_to_right(T1_file);

% Load brain model (current sources)
V = vb_load_cortex(brain_file, 'subj');

% Transform vertex coordinate to that of T1 image
Vana = vb_spm_right_to_analyze_right(V, Vdim, Vsize);

% Set parameters
Msize = 5;% marker size
dz = 5;% search radius for intersection triangle
xymode = 0;

h = figure;

% Show sagittal, coronal, and axial cuts
vcut = ['x','y','z'];% slice cut direction
label = {'Sagittal cut'; 'Coronal cut'; 'Axial cut'};
indx = fix([Vdim(1)*0.45 Vdim(2)/2 Vdim(3)*0.5 Vdim(3)*0.7]);% slice number
for n= 1:3
    % Plot T1 image
    subplot(1, 3, n)
    [strX,strY] = vb_plot_3d_image(B, indx(n), vcut(n), xymode);
    xlabel(strX);
    ylabel(strY);
    
    % Plot current sources on T1 image
    hold on
    vb_plot_vertex(Vana, vcut(n), indx(n), dz, Msize, 'y.', xymode);
    title(label{n})
end

% Save figure
vb_savefig_as_shown(h, fullfile(save_dir, p.sub))
disp(['This figure was saved as ' fullfile(save_dir, p.sub) '.png.'])