function check_lfnorm(p, prefix)
% Plot leadfield norm
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

% Show leadfield norm with angles
angle = [-90 0; 90 0; 0 90];
Nangle = size(angle,1);

% Set modality-specific parameters
switch p.dirname.modality
    case 'squid-meg'
        extention = '.meg.mat';
        ch_type  = [2, 3];
        ch_label = {'Axial', 'Planar'};

    case 'opm-meg'
        extention = '.meg.mat';
        ch_type  = [6, 5];
        ch_label = {'Z', 'Y'};

    case 'eeg'
        extention = '.eeg.mat';
        ch_type  = [1];
        ch_label = {'EEG'};
end

% Set preprocessed MEG/EEG file
ref_meg = fullfile(p.proj_root, p.dirname.modality, p.dirname.trial, [prefix '_' p.task '.info.mat']);

% Load channel info of active ch from reference file
[pos, channel_info] = vb_load_channel(ref_meg, true);
Nch = length(channel_info.Name);

% Load leadfild
% Note: LF is computed only for active ch
basis_file = fullfile(p.proj_root, p.dirname.modality, p.dirname.leadfield, [p.task '.basis.mat']);
G = vb_load_basis(basis_file);

% Select vertex to be shown
% (Currently, all vertices)
v_select = [];
if isempty(v_select)
    v_select = 1:size(G,1); % Select all
end
G = G(v_select,:);

% Load brain model
brain_file = fullfile(p.proj_root, p.dirname.brain, [p.struct_name, '.brain.mat']);
[V, F, xx, inf_C] = vb_load_cortex(brain_file, 'Inflate');
plot_parm = vb_set_plot_parm;

% Find corresponds index of specified ch_type
chix = [];
for cc=1:length(ch_type)
    chix = [chix, channel_info.Type==ch_type(cc)];
end

% In case of OPM/SQUID, add 'All' index
% by checking if chix is a part of all or not
% (In EEG, chix(:,1) covers all index of channel)
if sum(chix(:,1)) ~= Nch
    ch_label{end+1} = 'All';
    chix(:,end+1) = ones(Nch,1);
end

% Set column of subplot
Nax = length(ch_label);

% Set figure properties
set_fig_property(3, Nax, 10, 10);

h = figure;

% Calc lfnorm using all channels for consistent colorbar
lfn = sum(G.^2, 2).^0.5;
ma = max(lfn(:));

for ax = 1:Nax
    % Set ch
    chix_plot = find(chix(:,ax));
    nch = length(chix_plot);

    for an = 1:Nangle
        subplot(Nax, Nangle, an+3*(ax-1))
        
        % Calc lfnorm
        lfn = sum(G(:,chix_plot).^2, 2).^0.5;
        
        % Plot cortex and lfnorm
        vb_plot_cortex(plot_parm, V, F, inf_C, lfn, ma*0.05, ma);
        axis equal off
        colormap(my_parula)
        % Set view angle
        view(angle(an, :))

        if an == 2
            title(['Leadfield norm (' ch_label{ax} ': ' num2str(nch) ' channels)'])
        end
        if an==Nangle
            colorbar
        end
    end
end

% Save figure
fig_file = fullfile(p.fig_root, mfilename, p.dirname.modality, [p.sub '_' p.task]);
vb_savefig_as_shown(h, fig_file)
disp([fig_file '.png was saved.'])
