function show_erpimage(p, prefix_in)
% Show ERP image using eeglab function.
%
% Copyright (C) 2011, ATR All Rights Reserved.
% License : New BSD License(see VBMEG_LICENSE.txt)

disp(mfilename);
close all

% No additional prefix

% Set prefix of input file
if isempty(prefix_in)
    prefix_in_ = [];
else
    prefix_in_ = [prefix_in '_'];
end

% Set figure properties
set_fig_property(4, 2, 10, 10);

% Set parameters
% time_to_show_sec = [-0.1 0.3];% sec
twin_to_show_sec     = p.time_show_sec; % sec
twin_of_interest_sec = p.time_of_interest_sec; % sec

% Set modality-specific parameters
switch p.dirname.modality
    case 'opm-meg'
        unit_plot = 'pT';
        unit_coef = 10^12; % T -> pT
        plot_extra = true; % Plot extra-channels?
        % Specified extra channels will be shown
        chname_extra = {'EOG1', 'EOG2'};
        % In case of Motor, show EMG signals as well
        if strcmp(p.task, 'Motor')
            % Set reference channel
            chname_extra{end+1} = 'trigger_emg';
        end
    case 'squid-meg'
        unit_plot = 'pT';
        unit_coef = 10^12; % T -> pT
        plot_extra = false; % Plot extra-channels?
    case 'eeg'
        unit_plot = 'mV';
        unit_coef = 10^3; % V -> mV
        plot_extra = false; % Plot extra-channels?
end

% Load time information
data_file = fullfile(p.proj_root, p.dirname.modality, p.dirname.trial, [prefix_in_ p.task '.info.mat']);
[~, ~, time_info] = vb_load_meg_data(data_file);
[~, from_show_ix] = min(abs(time_info.time-twin_to_show_sec(1)));
[~, to_show_ix]   = min(abs(time_info.time-twin_to_show_sec(2)));
time_show_sec = time_info.time(from_show_ix:to_show_ix);

[~, from_peak_ix] = min(abs(time_show_sec - twin_of_interest_sec(1)));
[~, to_peak_ix]   = min(abs(time_show_sec - twin_of_interest_sec(2)));

%% Prepare data
% Set input file
data_file = fullfile(p.proj_root, p.dirname.modality, p.dirname.trial, [prefix_in_ p.task '.info.mat']);

% Load positions of channels
[pos, channel_info] = vb_load_channel(data_file);
Nch = size(pos,1);

% Load MEG data
data = vb_load_meg_data(data_file);
data = data.*unit_coef; 

if plot_extra
    % Load extra data
    loadspec = [];
    loadspec.ChannelType = 'EXTRA';
    loadspec.ChannelName = chname_extra;
    [data_ext, channel_info_ext, ~] = vb_load_meg_data(data_file, loadspec);
    Nch_ext = size(data_ext, 1);
    unit_plot_ext = '';
end

% Calc mean power within time of interests
y = mean(data(:, from_peak_ix:to_peak_ix, :), 3); % Trial-average
py = mean(y.^2, 2);

%% Show ERP
for ch=1:Nch
h = figure;
subplot(1,2,1)
% Plot erp image
erpdata = data(ch,from_show_ix:to_show_ix,:);
sortvar = zeros(1,size(erpdata,3));
ave_width = 3; % #trials to be averagesd across-trials (1 is no averaging)
decim = 1;
ch_title = [channel_info.Name{ch} ' (' num2str(ave_width) ' trials ave)'];
%[outdata, outvar, outtrials, limits, axhndls, erp, amps, coher, cohsig, ampsig, outamps, phsangles, phsamp, sortidx, erpsig] = ...
erpimage(erpdata, sortvar, time_show_sec*1000, ch_title, ave_width, decim, ...
    'srate',time_info.sample_frequency, ...
    'cbar', 'erp',1, 'caxis',1.0, ...
    'cbar_title', unit_plot);
colormap(my_parula())

subplot(1,2,2)
% Add sensor position
% vb_plot_sensor_2d_opm(pos(:,:), py, [], landmark, ch);
% vb_plot_sensor_2d_head_plot_add(gca);
vb_plot_sensor_2d(pos(:,:), py, [], true, ch);
axis square off
colorbar
title(['pos with power map (' num2str(twin_of_interest_sec(1)*1000) '-' num2str(twin_of_interest_sec(2)*1000) 'ms)'])

% Save figure
fig_file = fullfile(p.fig_root, mfilename, p.dirname.modality, p.task, p.sub, ['ch' num2str(ch)]);
vb_savefig_as_shown(h, fig_file)
disp([fig_file '.png was saved.'])
close(h)
end

%% Show ERP of extra-channels
if plot_extra
for ch=1:Nch_ext
h = figure;
subplot(1,2,1)
% Plot erp image
erpdata = data_ext(ch,from_show_ix:to_show_ix,:);
sortvar = zeros(1,size(erpdata,3));
ave_width = 3; % #trials to be averagesd across-trials (1 is no averaging)
decim = 1;
ch_title = [channel_info_ext.Name{ch} ' (' num2str(ave_width) ' trials ave)'];
%[outdata, outvar, outtrials, limits, axhndls, erp, amps, coher, cohsig, ampsig, outamps, phsangles, phsamp, sortidx, erpsig] = ...
erpimage(erpdata, sortvar, time_show_sec*1000, ch_title, ave_width, decim, ...
    'srate',time_info.sample_frequency, ...
    'cbar', 'erp',1, 'caxis',1.0, ...
    'cbar_title', unit_plot_ext);
colormap(my_parula())

% No sensor-position plot

% Save figure
fig_file = fullfile(p.fig_root, mfilename, p.dirname.modality, p.task, p.sub, ['ex' num2str(ch)]);
vb_savefig_as_shown(h, fig_file)
disp([fig_file '.png was saved.'])
close(h)
end
end



